@@ -2,13 +2,19 @@ from __future__ import annotations
 
 import abc
 import enum
+import sys
 from collections.abc import Sequence
 from dataclasses import dataclass, field
-from datetime import datetime
+from datetime import datetime, time, tzinfo
 from decimal import Decimal
 
 from yarl import URL
 
+if sys.version_info >= (3, 9):
+    from zoneinfo import ZoneInfo
+else:
+    from backports.zoneinfo import ZoneInfo
+
 
 class NotificationType(str, enum.Enum):
     SUCCESS = "success"
@@ -124,6 +130,9 @@ class NodePool:
 
     zones: tuple[str, ...] | None = None
 
+    cpu_min_watts: float = 0.0
+    cpu_max_watts: float = 0.0
+
 
 @dataclass(frozen=True)
 class StorageInstance:
@@ -542,11 +551,33 @@ class ClusterStatus(str, enum.Enum):
     FAILED = "failed"
 
 
+@dataclass(frozen=True)
+class EnergySchedulePeriod:
+    # ISO 8601 weekday number (1-7)
+    weekday: int
+    start_time: time
+    end_time: time
+
+
+@dataclass(frozen=True)
+class EnergySchedule:
+    name: str
+    periods: Sequence[EnergySchedulePeriod] = ()
+    price_per_kwh: Decimal = Decimal("0")
+
+
+@dataclass(frozen=True)
+class EnergyConfig:
+    co2_grams_eq_per_kwh: float = 0
+    schedules: Sequence[EnergySchedule] = ()
+
+
 @dataclass(frozen=True)
 class Cluster:
     name: str
     status: ClusterStatus
     created_at: datetime
+    timezone: tzinfo = ZoneInfo("UTC")
     platform_infra_image_tag: str | None = None
     cloud_provider: CloudProvider | None = None
     credentials: CredentialsConfig | None = None
@@ -560,3 +591,4 @@ class Cluster:
     disks: DisksConfig | None = None
     buckets: BucketsConfig | None = None
     ingress: IngressConfig | None = None
+    energy: EnergyConfig | None = None
