@@ -1,6 +1,7 @@
 from __future__ import annotations
 
-from datetime import datetime
+import sys
+from datetime import datetime, time, tzinfo
 from decimal import Decimal
 from typing import Any
 
@@ -33,6 +34,9 @@ from .entities import (
     EFSPerformanceMode,
     EFSThroughputMode,
     EMCECSCredentials,
+    EnergyConfig,
+    EnergySchedule,
+    EnergySchedulePeriod,
     GoogleCloudProvider,
     GoogleFilestoreTier,
     GoogleStorage,
@@ -70,6 +74,11 @@ from .entities import (
     VolumeConfig,
 )
 
+if sys.version_info >= (3, 9):
+    from zoneinfo import ZoneInfo
+else:
+    from backports.zoneinfo import ZoneInfo
+
 
 class EntityFactory:
     @classmethod
@@ -180,6 +189,8 @@ class EntityFactory:
         dns = payload.get("dns")
         cloud_provider = payload.get("cloud_provider")
         credentials = payload.get("credentials")
+        timezone = self._create_timezone(payload.get("timezone"))
+        energy = payload.get("energy")
         return Cluster(
             name=payload["name"],
             status=ClusterStatus(payload["status"]),
@@ -201,6 +212,8 @@ class EntityFactory:
             else None,
             credentials=self.create_credentials(credentials) if credentials else None,
             created_at=datetime.fromisoformat(payload["created_at"]),
+            timezone=timezone,
+            energy=self.create_energy(energy, timezone=timezone) if energy else None,
         )
 
     def create_orchestrator(self, payload: dict[str, Any]) -> OrchestratorConfig:
@@ -413,6 +426,8 @@ class EntityFactory:
             idle_size=payload.get("idle_size", NodePool.idle_size),
             is_preemptible=payload.get("is_preemptible", NodePool.is_preemptible),
             zones=payload.get("zones", NodePool.zones),
+            cpu_min_watts=payload.get("cpu_min_watts", NodePool.cpu_min_watts),
+            cpu_max_watts=payload.get("cpu_max_watts", NodePool.cpu_max_watts),
         )
 
     def _create_aws_storage(self, payload: dict[str, Any]) -> AWSStorage:
@@ -626,6 +641,48 @@ class EntityFactory:
             region_name=payload["region_name"],
         )
 
+    def _create_timezone(self, name: str | None) -> tzinfo:
+        if not name:
+            return Cluster.timezone
+        try:
+            return ZoneInfo(name)
+        except Exception:
+            raise ValueError(f"invalid timezone: {name}")
+
+    def create_energy(
+        self, payload: dict[str, Any], *, timezone: tzinfo
+    ) -> EnergyConfig:
+        return EnergyConfig(
+            co2_grams_eq_per_kwh=payload["co2_grams_eq_per_kwh"],
+            schedules=[
+                self._create_energy_schedule(s, timezone)
+                for s in payload.get("schedules", ())
+            ],
+        )
+
+    def _create_energy_schedule(
+        self, payload: dict[str, Any], timezone: tzinfo
+    ) -> EnergySchedule:
+        return EnergySchedule(
+            name=payload["name"],
+            price_per_kwh=Decimal(payload["price_per_kwh"]),
+            periods=[
+                self._create_energy_schedule_period(p, timezone=timezone)
+                for p in payload.get("periods", ())
+            ],
+        )
+
+    def _create_energy_schedule_period(
+        self, payload: dict[str, Any], *, timezone: tzinfo
+    ) -> EnergySchedulePeriod:
+        start_time = time.fromisoformat(payload["start_time"]).replace(tzinfo=timezone)
+        end_time = time.fromisoformat(payload["end_time"]).replace(tzinfo=timezone)
+        return EnergySchedulePeriod(
+            weekday=payload["weekday"],
+            start_time=start_time,
+            end_time=end_time,
+        )
+
 
 class PayloadFactory:
     @classmethod
@@ -877,6 +934,7 @@ class PayloadFactory:
     def create_metrics(cls, metrics: MetricsConfig) -> dict[str, Any]:
         return {"url": str(metrics.url)}
 
+    @classmethod
     def create_secrets(cls, secrets: SecretsConfig) -> dict[str, Any]:
         return {"url": str(secrets.url)}
 
@@ -922,8 +980,7 @@ class PayloadFactory:
 
     @classmethod
     def create_node_pool(cls, node_pool: NodePool) -> dict[str, Any]:
-        node_pool
-        result = {
+        result: dict[str, Any] = {
             "name": node_pool.name,
             "role": node_pool.role.value,
             "min_size": node_pool.min_size,
@@ -959,4 +1016,36 @@ class PayloadFactory:
             result["is_preemptible"] = node_pool.is_preemptible
         if node_pool.zones:
             result["zones"] = node_pool.zones
+        if node_pool.cpu_min_watts:
+            result["cpu_min_watts"] = node_pool.cpu_min_watts
+        if node_pool.cpu_max_watts:
+            result["cpu_max_watts"] = node_pool.cpu_max_watts
         return result
+
+    @classmethod
+    def create_energy(cls, energy: EnergyConfig) -> dict[str, Any]:
+        return {
+            "co2_grams_eq_per_kwh": energy.co2_grams_eq_per_kwh,
+            "schedules": [cls._create_energy_schedule(s) for s in energy.schedules],
+        }
+
+    @classmethod
+    def _create_energy_schedule(cls, schedule: EnergySchedule) -> dict[str, Any]:
+        payload: dict[str, Any] = {
+            "name": schedule.name,
+            "price_per_kwh": str(schedule.price_per_kwh),
+        }
+        periods = [cls._create_energy_schedule_period(p) for p in schedule.periods]
+        if periods:
+            payload["periods"] = periods
+        return payload
+
+    @classmethod
+    def _create_energy_schedule_period(
+        cls, period: EnergySchedulePeriod
+    ) -> dict[str, Any]:
+        return {
+            "weekday": period.weekday,
+            "start_time": period.start_time.strftime("%H:%M"),
+            "end_time": period.end_time.strftime("%H:%M"),
+        }
