@@ -1,7 +1,8 @@
 from __future__ import annotations
 
+import sys
 from dataclasses import replace
-from datetime import datetime
+from datetime import datetime, time
 from decimal import Decimal
 from typing import Any
 from unittest import mock
@@ -35,6 +36,9 @@ from neuro_config_client.entities import (
     EFSPerformanceMode,
     EFSThroughputMode,
     EMCECSCredentials,
+    EnergyConfig,
+    EnergySchedule,
+    EnergySchedulePeriod,
     GoogleCloudProvider,
     GoogleFilestoreTier,
     GoogleStorage,
@@ -71,6 +75,11 @@ from neuro_config_client.entities import (
 )
 from neuro_config_client.factories import EntityFactory, PayloadFactory
 
+if sys.version_info >= (3, 9):
+    from zoneinfo import ZoneInfo
+else:
+    from backports.zoneinfo import ZoneInfo
+
 
 class TestEntityFactory:
     @pytest.fixture
@@ -96,6 +105,7 @@ class TestEntityFactory:
             {
                 "name": "default",
                 "status": "blank",
+                "timezone": "America/Los_Angeles",
                 "orchestrator": {
                     "job_hostname_template": "{job_id}.jobs-dev.neu.ro",
                     "job_fallback_hostname": "default.jobs-dev.neu.ro",
@@ -131,6 +141,7 @@ class TestEntityFactory:
 
         assert result.name == "default"
         assert result.status == ClusterStatus.BLANK
+        assert result.timezone == ZoneInfo("America/Los_Angeles")
         assert result.orchestrator
         assert result.storage
         assert result.registry
@@ -144,6 +155,17 @@ class TestEntityFactory:
         assert result.credentials
         assert result.created_at
 
+    def test_create_cluster__invalid_timezone(self, factory: EntityFactory) -> None:
+        with pytest.raises(ValueError, match="invalid timezone"):
+            factory.create_cluster(
+                {
+                    "name": "default",
+                    "status": "blank",
+                    "created_at": str(datetime.now()),
+                    "timezone": "invalid",
+                }
+            )
+
     def test_create_orchestrator(self, factory: EntityFactory) -> None:
         result = factory.create_orchestrator(
             {
@@ -858,6 +880,8 @@ class TestEntityFactory:
                     "gpu_model": "nvidia-tesla-k80",
                     "price": "0.9",
                     "currency": "USD",
+                    "cpu_min_watts": 0.1,
+                    "cpu_max_watts": 100,
                 },
             ],
         }
@@ -895,6 +919,8 @@ class TestEntityFactory:
                     price=Decimal("0.9"),
                     currency="USD",
                     machine_type="gpu-machine-1xk80",
+                    cpu_min_watts=0.1,
+                    cpu_max_watts=100,
                 ),
             ],
             storage=None,
@@ -955,6 +981,8 @@ class TestEntityFactory:
                     "gpu_model": "nvidia-tesla-k80",
                     "price": "0.9",
                     "currency": "USD",
+                    "cpu_min_watts": 0.1,
+                    "cpu_max_watts": 100,
                 },
             ],
             "storage": {
@@ -1010,6 +1038,8 @@ class TestEntityFactory:
                     gpu_model="nvidia-tesla-k80",
                     price=Decimal("0.9"),
                     currency="USD",
+                    cpu_min_watts=0.1,
+                    cpu_max_watts=100,
                 ),
             ],
             storage=VCDStorage(
@@ -1358,6 +1388,47 @@ class TestEntityFactory:
             storage_profile_names=["neuro-storage"],
         )
 
+    def test_create_energy(self, factory: EntityFactory) -> None:
+        timezone = ZoneInfo("America/Los_Angeles")
+        energy = factory.create_energy(
+            {
+                "co2_grams_eq_per_kwh": 100,
+                "schedules": [
+                    {"name": "default", "price_per_kwh": "123.4"},
+                    {
+                        "name": "green",
+                        "price_per_kwh": "123.4",
+                        "periods": [
+                            {"weekday": 1, "start_time": "23:00", "end_time": "00:00"}
+                        ],
+                    },
+                ],
+            },
+            timezone=timezone,
+        )
+
+        assert energy == EnergyConfig(
+            co2_grams_eq_per_kwh=100,
+            schedules=[
+                EnergySchedule(
+                    name="default",
+                    price_per_kwh=Decimal("123.4"),
+                    periods=[],
+                ),
+                EnergySchedule(
+                    name="green",
+                    price_per_kwh=Decimal("123.4"),
+                    periods=[
+                        EnergySchedulePeriod(
+                            weekday=1,
+                            start_time=time(hour=23, minute=0, tzinfo=timezone),
+                            end_time=time(hour=0, minute=0, tzinfo=timezone),
+                        )
+                    ],
+                ),
+            ],
+        )
+
 
 class TestPayloadFactory:
     @pytest.fixture
@@ -1844,6 +1915,8 @@ class TestPayloadFactory:
             currency="rabbits",
             is_preemptible=True,
             zones=("here", "there"),
+            cpu_min_watts=0.01,
+            cpu_max_watts=1000,
         )
 
     def test_node_pool(self, factory: PayloadFactory, node_pool: NodePool) -> None:
@@ -1868,6 +1941,8 @@ class TestPayloadFactory:
             "zones": ("here", "there"),
             "price": "180",
             "currency": "rabbits",
+            "cpu_min_watts": 0.01,
+            "cpu_max_watts": 1000,
         }
 
         np = replace(
@@ -1895,4 +1970,42 @@ class TestPayloadFactory:
             "gpu_model": "some-gpu-model",
             "price": "180",
             "currency": "rabbits",
+            "cpu_min_watts": 0.01,
+            "cpu_max_watts": 1000,
+        }
+
+    def test_create_energy(self, factory: PayloadFactory) -> None:
+        timezone = ZoneInfo("America/Los_Angeles")
+        energy = factory.create_energy(
+            EnergyConfig(
+                co2_grams_eq_per_kwh=100,
+                schedules=[
+                    EnergySchedule(name="default", price_per_kwh=Decimal("246.8")),
+                    EnergySchedule(
+                        name="green",
+                        price_per_kwh=Decimal("123.4"),
+                        periods=[
+                            EnergySchedulePeriod(
+                                weekday=1,
+                                start_time=time(hour=23, minute=0, tzinfo=timezone),
+                                end_time=time(hour=0, minute=0, tzinfo=timezone),
+                            )
+                        ],
+                    ),
+                ],
+            )
+        )
+
+        assert energy == {
+            "co2_grams_eq_per_kwh": 100,
+            "schedules": [
+                {"name": "default", "price_per_kwh": "246.8"},
+                {
+                    "name": "green",
+                    "price_per_kwh": "123.4",
+                    "periods": [
+                        {"weekday": 1, "start_time": "23:00", "end_time": "00:00"}
+                    ],
+                },
+            ],
         }
